%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This script will take the output file from dorsoventral_model.m and
% produce plots of the distributions of field sizes across place cell
% groups, and the number of active cells per group, (Lyttle et al 2013)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all
load example_data.mat

nummod = 30;        % has to match nPlaceMod
numit = 10;         % has to match numit
areaind = cell(1,nummod);
numind = cell(1,nummod);
G = [];
D = [];

areasfull = [];
for k = 1:nummod
    for i = 1:numit
        numbers(i) = 100*length(find(output{i}{1}{k}>0))/length(output{i}{1}{k});
        areaind{k} = [areaind{k} output{i}{3}{k}];
        numind{k} = [numind{k} output{i}{1}{k}];
    end
    areaind{k} = areaind{k}(areaind{k}>0);
    areaind{k} = areaind{k}/100;
    areasfull = [areasfull areaind{k}];
    G1 = k*ones(1,length(areaind{k}));
    G = [G G1];
    D = [D areaind{k}];
    p(:,k) = quantile(areaind{k}, [0.05 0.95]);
    nums(k) = mean(numbers);
    devs(k) = std(numbers);
end


f=boxplot(D,G,'whisker',2);
set(f,'LineWidth',1.5);
set(f, 'LineStyle','-');
set(f(7,:),'Visible','off');
set(gca,'XTickLabel',{' '})
ylabel('% active area')    
xlabel('Dorsal <----> Ventral')
title('Figure 4C')  

% Replace upper end y value of whisker
h = flipud(findobj(gca,'Tag','Upper Whisker'));
for j=1:length(h);
   ydata = get(h(j),'YData');
   ydata(2) = p(2,j);
   set(h(j),'YData',ydata);
end

% Replace all y values of adjacent value
h = flipud(findobj(gca,'Tag','Upper Adjacent Value'));
for j=1:length(h);
   ydata = get(h(j),'YData');
   ydata(:) = p(2,j);
   set(h(j),'YData',ydata);
end

% Replace lower end y value of whisker
h = flipud(findobj(gca,'Tag','Lower Whisker'));
for j=1:length(h);
   ydata = get(h(j),'YData');
   ydata(1) = p(1,j);
   set(h(j),'YData',ydata);
end

% Replace all y values of adjacent value
h = flipud(findobj(gca,'Tag','Lower Adjacent Value'));
for j=1:length(h);
   ydata = get(h(j),'YData');
   ydata(:) = p(1,j);
   set(h(j),'YData',ydata);
end
ylim([0 100]);
box off;

hh=figure();
errorbar(nums,devs, 'LineWidth',1.5, 'Color','black','LineStyle','none', 'Marker','+')
ymax = nummod+1;

ylim([0 100])
xlim([0,ymax])
box off
ylabel('% active cells')     
xlabel('Dorsal <----> Ventral') 
title('Figure 6')  




